import * as imports from "#imports";
export default imports.defineCachedEventHandler(async () => {
  const { releases: releasesConfig } = imports.useRuntimeConfig().github;
  let releases = await fetchGitHubReleases(releasesConfig);
  if (releasesConfig.parse && typeof imports.contentParse === "function") {
    releases = await Promise.all(releases.map(async (release) => ({
      ...release,
      ...await imports.contentParse(`${release.name}.md`, release.body)
    })));
  }
  releases.sort((a, b) => a.v !== b.v ? b.v - a.v : a.date - b.date);
  return releases;
}, {
  maxAge: 60
});
const normalizeReleaseName = (name) => {
  name = name.replace("Release ", "");
  if (!name.match(/^[a-zA-Z]/)) {
    name = `v${name}`;
  }
  return name;
};
export async function fetchGitHubReleases({ api, repo, token }) {
  const url = `${api}/${repo}/releases`;
  const rawReleases = await $fetch(url, {
    headers: {
      Authorization: token ? `token ${token}` : void 0
    }
  }).catch((err) => {
    console.warn(`Cannot fetch GitHub releases on ${url} [${err.response?.status}]`);
    console.info("Make sure to provide GITHUB_TOKEN environment in `.env`");
    if (err.response.status !== 403) {
      console.info("To disable fetching releases, set `github.releases` to `false` in `nuxt.config.ts`");
    }
    return [];
  });
  return rawReleases.filter((r) => !r.draft).map((release) => {
    return {
      name: normalizeReleaseName(release.name || release.tag_name),
      v: +normalizeReleaseName(release.tag_name).substring(1, 2),
      date: release.published_at,
      body: release.body
    };
  });
}
